# CLASSES in the mvabund package

# basic objects
setClass("mvabund" ) 
setClass("formulaUnimva" )
setClass("mvformula")

# Model classes
setClass("glm1path" ) 
setClass("manylm")
setClass("manyglm")
setClass("traitglm" ) 

# summary classes
setClass("summary.manylm")
setClass("summary.manyglm")

# anova classes
setClass("anova.manylm")
setClass("anova.manyglm")
